@@ -19,6 +19,7 @@ my @attributes = qw(
     facets
     query
     parsed_query
+    json_query
     title
     link
     author
@@ -27,7 +28,7 @@ my @attributes = qw(
 );
 __PACKAGE__->mk_accessors( @attributes, qw( debug pps ) );
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 sub init {
     my $self = shift;
@@ -138,6 +139,11 @@ An interator object behaving like SWISH::Prog::Results.
 
 As returned by Search::Query.
 
+=item json_query
+
+Same as parsed_query, but the object tree is JSON encoded instead
+of stringified.
+
 =item author
 
 =item pps
